<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Gedmo\Mapping\Annotation as Gedmo;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\Entity()
 * @ORM\Table(name="dedi_blog_article_translation")
 */
class ArticleTranslation extends AbstractReferableTranslation implements ResourceInterface
{
    /**
     * @ORM\Column(type="integer", nullable=false)
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected ?int $id = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="article_translation_slug")
     * @Gedmo\Slug(fields={"title"}, unique=true)
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $slug = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="article_translation_title")
     * @Assert\NotBlank(groups={"default", "sylius"})
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $title = null;

    /**
     * @ORM\Column(type="text", nullable=false, name="article_translation_content")
     * @Assert\NotBlank(groups={"default", "sylius"})
     */
    protected ?string $content = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(?string $slug): self
    {
        $this->slug = $slug;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(?string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(?string $content): self
    {
        $this->content = $content;

        return $this;
    }
}
